@@ -1,8 +1,8 @@
 #' Create a visual table from a summariseClinicalRecord() output.
 #'
 #' @param result Output from summariseClinicalRecords().
-#' @param type Type of formatting output table, either "gt" or "flextable".
-#' @return A gt or flextable object with the summarised data.
+#' @param type Type of formatting output table. See `visOmopResults::tableType()` for allowed options.
+#' @return A formatted table object with the summarised data.
 #' @export
 #' @examples
 #' \donttest{
@@ -45,19 +45,22 @@ tableClinicalRecords <- function(result,
   }
 
   header <- c("cdm_name")
-
+  custom_order <- c("Number records", "Number subjects", "Records per person", "In observation", "Domain", "Source vocabulary", "Standard concept", "Type concept id")
   result |>
     formatColumn(c("variable_name", "variable_level")) |>
+    dplyr::mutate(variable_name = factor(.data$variable_name, levels = custom_order)) |>
     dplyr::arrange(.data$variable_name, .data$variable_level) |>
     visOmopResults::visOmopTable(
       type = type,
       estimateName = c(
         "N (%)" = "<count> (<percentage>%)",
         "N" = "<count>",
-        "Mean (SD)" = "<mean> (<sd>)"
+        "Mean (SD)" = "<mean> (<sd>)",
+        "Median [Q25 - Q75]" = "<median> [<q25> - <q75>]",
+        "Range [min to max]" = "[<min> to <max>]"
       ),
       header = header,
       rename = c("Database name" = "cdm_name"),
       groupColumn = c("omop_table", omopgenerics::strataColumns(result))
-    )
+    ) |> suppressMessages()
 }
