@@ -26,10 +26,10 @@ test_that("table omop snapshot works", {
 test_that("works with mockOmopSketch", {
   skip_on_cran()
   cdm <- mockOmopSketch()
-  expect_no_error(x <- tableOmopSnapshot(summariseOmopSnapshot(cdm)))
+  expect_no_error(x <- tableOmopSnapshot(summariseOmopSnapshot(cdm)) |> suppressWarnings())
   expect_true(inherits(x, "gt_tbl"))
-
-  x <- summariseOmopSnapshot(cdm) |> dplyr::filter(result_id == 0.1)
+  expect_warning(x <- summariseOmopSnapshot(cdm))
+  x <- x |> dplyr::filter(result_id == 0.1)
   expect_warning(inherits(tableOmopSnapshot(x), "gt_tbl"))
 
   # Check result type
